API
===

.. automodule:: tickit_devices

    ``tickit_devices``
    ------------------

This is the internal API reference for tickit-devices

.. data:: tickit_devices.__version__
    :type: str

    Version number as calculated by https://github.com/pypa/setuptools_scm
